==> gums-1.4.0-pre1.tar.gz: gums-1.4.0-pre1/gums-core/src/main/java/gov/bnl/gums/GridUser.java <==
/*
 * GridUser.java
 *
 * Created on August 31, 2004, 4:00 PM
 */

package gov.bnl.gums;

import gov.bnl.gums.userGroup.UserGroup;

import java.lang.ref.SoftReference;

import org.apache.log4j.Logger;
import javax.persistence.*;

/** 
 * Represent a GRID Identity in GUMS, which is a certificate with its DN and FQAN.
 *
 * @author  Gabriele Carcassi, Jay Packard
 */
@Entity
public class GridUser {
    static protected Logger log = Logger.getLogger(GridUser.class);

    protected FQAN fqanObj;
    
    // persistent fields
	protected long id;
	protected String dn;
	protected String email;
	protected SoftReference<UserGroup> userGroupRef = null;
    
    /**
     * Creates a GRID credentail with no DN and FQAN.
     */
    public GridUser() {
    }
    
    /**
     * Creates a GRID credential with DN.
     */
    public GridUser(String userDN) {
    	this(userDN, null, null, false);
    }
    
    /**
     * Creates a GRID credential with DN and FQAN.
     */
    public GridUser(String userDN, String fqan) {
        this(userDN, fqan, null, true);
    }
    
    /**
     * Creates a GRID credential with DN and FQAN.
     */
    public GridUser(String userDN, String fqan, boolean enforceFqanWellFormedness) {
        this(userDN, fqan, null, enforceFqanWellFormedness);
    }
 
    /**
     * Creates a new object representing a Grid credential.
     * 
     * @param userDN the DN of the user certificate (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     * @param fqan The Fully Qualified Attribute name (i.e. "/atlas/production/Role=Leader")
     * @param email
     */
    public GridUser(String userDN, String fqan, String email) {
    	this(userDN, fqan, email, true);
    }
    
    /**
     * Creates a new object representing a Grid credential.
     * 
     * @param userDN the DN of the user certificate (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     * @param fqan The Fully Qualified Attribute name (i.e. "/atlas/production/Role=Leader")
     * @param email
     */
    public GridUser(String userDN, String fqan, String email, boolean enforceFqanWellFormedness) {
        setDn(userDN);
        if (fqan!=null && fqan.length()>0)
        	setFqanObj(new FQAN(fqan, enforceFqanWellFormedness));
       	setEmail(email);
    }

  /**
     * @param user
     * @return true if user DN element matches
     */
    public int compareDn(GridUser user) {
		if (this.dn == null || user.dn == null)
			return (this.dn==user.dn ? 0 : (user.dn==null ? -1: 1));
    	return this.compareDn( user.getDn() );
    }
    
    /**
     * @param userDn
     * @return true if user DN element matches
     */
    public int compareDn(String userDn) {
		if (this.dn == null || userDn == null)
			return (this.dn==userDn ? 0 : (userDn==null ? -1: 1));
    	return this.dn.compareTo( userDn );//compareToIgnoreCase( userDn );
    }
    
    /**
     * A GridUser will be equal only to another GridUser with the same DN and FQAN.
     * 
     * @param obj another object
     * @return true if the object was a GridUser with equivalent credentials
     */
    public boolean equals(Object obj) {
    	if (obj==null)
    		return false;
        GridUser user = (GridUser) obj;
        if ((user.getDn() == null) ? dn != null : (user.compareDn(dn)!=0)) {
            if (log.isTraceEnabled()) {
                log.trace(this + " !equals " + obj + " for different DN");
            }
            return false;
        }
        if ((user.fqanObj == null) ? fqanObj != null : (!user.fqanObj.equals(fqanObj))) {
            if (log.isTraceEnabled()) {
                log.trace(this + " !equals " + obj + " for different FQAN");
            }
            return false;
        }
        if (log.isTraceEnabled()) {
            log.trace(this + " equals " + obj);
        }
        return true;
    }
    
    /**
     * Retrieve the certificate DN of the user.
     * 
     * @return The certificate DN (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     */
    public String getDn() {
        return this.dn;
    }
    
    /**
     * Retrieve the email of the user.
     * 
     * @return The email
     */
    public String getEmail() {
        return this.email;
    }

    /**
     * Retrieve the string representation of the VOMS Fully Qualified Attribute name.
     * 
     * @return The string representation of the VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    public String getFqan() {
        return fqanObj==null ? null : this.fqanObj.toString();
    }
    
    /**
     * Retrieve VOMS Fully Qualified Attribute name.
     * 
     * @return The VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    @Transient
    public FQAN getFqanObj() {
        return this.fqanObj;
    }
    
	@ManyToOne
    @JoinColumn(name="userGroup")
    public UserGroup getUserGroup() {
		return userGroupRef == null ? null : userGroupRef.get();
	}
    
    /**
     * Changed to reflect the change in equals, as in Object contract.
     * 
     * @return A hash created from the DN and FQAN.
     */
    public int hashCode() {
        if (dn != null)
            return dn.hashCode();
        if (fqanObj != null)
            return fqanObj.getFqan().hashCode();
        return 0;
    }
    
    /**
     * Initialize from string array.
     * 
     * @return A hash created from the DN and FQAN.
     */
    public void initialize(String[] elements) {
    	if (elements.length >= 1)
    		dn = elements[0].trim();
    	if (elements.length >= 2)
    		fqanObj = new FQAN(elements[1].trim());
    }
    
    /**
     * Changes the certificate DN for the Grid credential.
     * 
     * @param certificateDN A GRID certificate DN (i.e. "/DC=org/DC=doegrids/OU=People/CN=Gabriele Carcassi")
     */
    public void setDn(String certificateDN) {
        this.dn = certificateDN;//removeSpaces(certificateDN);
    }
 
    /**
     * Changes the email.
     * 
     * @param email
     */
    public void setEmail(String email) {
        this.email = email;
    }
    
    /**
     * Sets the VOMS Fully Qualified Attribute name for the credential.
     * 
     * @param voFQAN The VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    public void setFqan(String fqan) {
    	if (fqan == null)
    		return;
        this.fqanObj = new FQAN(fqan);
    }
    
    /**
     * Sets the VOMS Fully Qualified Attribute name for the credential.
     * 
     * @param voFQAN The VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    public void setFqanObj(FQAN voFQAN) {
        this.fqanObj = voFQAN;
    }
    
	public void setUserGroup(UserGroup userGroup) {
		this.userGroupRef = new SoftReference<UserGroup>(userGroup);
	}

	/**
     * Returns a legible String representation for the credentail.
     * 
     * @return String reprentation of the credential (i.e. "GridID[/DC=org/DC=doegrids/OU=People/CN=Gabriele Carcassi]")
     */
    public String toString() {
        if (fqanObj == null) {
            //return "GridID[" + dn + "]";
            return dn;
        }
//        return "GridID[" + dn + ", " + fqanObj + "]";
        return dn + "," + fqanObj;
    }

	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@SuppressWarnings("unused")
    private long getId() {
		return id;
	}

	@SuppressWarnings("unused")
	private void setId(long id) {
		this.id = id;
	}
    
    /**
     * Trim and remove two or more consecutive strings
     * 
     * @param str
     * @return new string
     */
    /*private String removeSpaces(String str) {
    	if (str!=null) {
    		str = str.trim();
	    	String tempStr;
	    	while ( !(tempStr=str.replaceAll("\\s\\s", " ")).equals(str) )
	    		str = tempStr;	   	    	
    	}
   		return str;
    }*/
    
}

==> gums-1.5.1.tar.gz: gums-1.5.1/gums-core/src/main/java/gov/bnl/gums/GridUser.java <==
/*
 * GridUser.java
 *
 * Created on August 31, 2004, 4:00 PM
 */

package gov.bnl.gums;

import org.apache.log4j.Logger;

/** 
 * Represent a GRID Identity in GUMS, which is a certificate with its DN and FQAN.
 *
 * @author  Gabriele Carcassi, Jay Packard
 */
public final class GridUser {
    private Logger log = Logger.getLogger(GridUser.class);
    private String certificateDN;
    private FQAN voFQAN;
    private String email;
    private boolean verified;
    
    /**
     * Creates a GRID credentail with no DN and FQAN.
     */
    public GridUser() {
    }
    
    /**
     * Creates a GRID credential with DN.
     */
    public GridUser(String userDN) {
    	this(userDN, null, null, false);
    }
    
    /**
     * Creates a GRID credential with DN and FQAN.
     */
    public GridUser(String userDN, String fqan) {
        this(userDN, fqan, null, true);
    }
    
    /**
     * Creates a GRID credential with DN and FQAN.
     */
    public GridUser(String userDN, String fqan, boolean enforceFqanWellFormedness) {
        this(userDN, fqan, null, enforceFqanWellFormedness);
    }
 
    /**
     * Creates a new object representing a Grid credential.
     * 
     * @param userDN the DN of the user certificate (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     * @param fqan The Fully Qualified Attribute name (i.e. "/atlas/production/Role=Leader")
     * @param email
     */
    public GridUser(String userDN, String fqan, String email) {
    	this(userDN, fqan, email, true);
    }
    
    /**
     * Creates a new object representing a Grid credential.
     * 
     * @param userDN the DN of the user certificate (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     * @param fqan The Fully Qualified Attribute name (i.e. "/atlas/production/Role=Leader")
     * @param email
     */
    public GridUser(String userDN, String fqan, String email, boolean enforceFqanWellFormedness) {
        setCertificateDN(userDN);
        if (fqan!=null && fqan.length()>0)
        	setVoFQAN(new FQAN(fqan, enforceFqanWellFormedness));
       	setEmail(email);
        setVerified(false);
    }

  /**
     * @param user
     * @return true if user DN element matches
     */
    public int compareDn(GridUser user) {
		if (this.certificateDN == null || user.certificateDN == null)
			return (this.certificateDN==user.certificateDN ? 0 : (user.certificateDN==null ? -1: 1));
    	return this.compareDn( user.getCertificateDN() );
    }
    
    /**
     * @param userDn
     * @return true if user DN element matches
     */
    public int compareDn(String userDn) {
		if (this.certificateDN == null || userDn == null)
			return (this.certificateDN==userDn ? 0 : (userDn==null ? -1: 1));
    	return this.certificateDN.compareTo( userDn );//compareToIgnoreCase( userDn );
    }
    
    /**
     * A GridUser will be equal only to another GridUser with the same DN and FQAN.
     * 
     * @param obj another object
     * @return true if the object was a GridUser with equivalent credentials
     */
    public boolean equals(Object obj) {
        GridUser user = (GridUser) obj;
        if ((user.getCertificateDN() == null) ? certificateDN != null : (user.compareDn(certificateDN)!=0)) {
            if (log.isTraceEnabled()) {
                log.trace(this + " !equals " + obj + " for different DN");
            }
            return false;
        }
        if ((user.voFQAN == null) ? voFQAN != null : (!user.voFQAN.equals(voFQAN))) {
            if (log.isTraceEnabled()) {
                log.trace(this + " !equals " + obj + " for different FQAN");
            }
            return false;
        }
        if (verified != user.getVerified()) {
            return false;
        }
        if (log.isTraceEnabled()) {
            log.trace(this + " equals " + obj);
        }
        return true;
    }
    
    /**
     * Retrieve the certificate DN of the user.
     * 
     * @return The certificate DN (i.e. "/DC=org/DC=doegrids/OU=People/CN=John Smith")
     */
    public String getCertificateDN() {
        return this.certificateDN;
    }
    
    /**
     * Retrieve the email of the user.
     * 
     * @return The email
     */
    public String getEmail() {
        return this.email;
    }

    /**
     * Retrieve the VOMS Fully Qualified Attribute name.
     * 
     * @return The VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    public FQAN getVoFQAN() {
        return this.voFQAN;
    }

    /**
     * Returns true if the FQAN was verified on the client.
     */
    public boolean getVerified() {
        return this.verified;
    }

    /**
     * Changed to reflect the change in equals, as in Object contract.
     * 
     * @return A hash created from the DN and FQAN.
     */
    public int hashCode() {
        if (certificateDN != null) {
            return certificateDN.hashCode();
        }
        if (voFQAN != null) {
            return voFQAN.getFqan().hashCode();
        }
        return 0;
    }

    /**
     * Indicate whether the FQAN was verified on the client.
     */
    public void setVerified(boolean verified) {
        this.verified = verified;
    }

    /**
     * Changes the certificate DN for the Grid credential.
     * 
     * @param certificateDN A GRID certificate DN (i.e. "/DC=org/DC=doegrids/OU=People/CN=Gabriele Carcassi")
     */
    public void setCertificateDN(String certificateDN) {
        this.certificateDN = certificateDN;//removeSpaces(certificateDN);
    }
    
    /**
     * Changes the email.
     * 
     * @param email
     */
    public void setEmail(String email) {
        this.email = email;
    }
    
    /**
     * Sets the VOMS Fully Qualified Attribute name for the credential.
     * 
     * @param voFQAN The VOMS FQAN selected with voms-proxy-init (i.e. "/atlas/production/Role=Leader")
     */
    public void setVoFQAN(FQAN voFQAN) {
        this.voFQAN = voFQAN;
    }
    
    /**
     * Returns a legible String representation for the credentail.
     * 
     * @return String reprentation of the credential (i.e. "GridID[/DC=org/DC=doegrids/OU=People/CN=Gabriele Carcassi]")
     */
    public String toString() {
        if (voFQAN == null) {
            return "GridID[" + certificateDN + "]";
        }
        return "GridID[" + certificateDN + ", " + voFQAN + "]";
    }
    
    /**
     * Trim and remove two or more consecutive strings
     * 
     * @param str
     * @return new string
     */
    private String removeSpaces(String str) {
    	if (str!=null) {
    		str = str.trim();
	    	String tempStr;
	    	while ( !(tempStr=str.replaceAll("\\s\\s", " ")).equals(str) )
	    		str = tempStr;	   	    	
    	}
   		return str;
    }
    
}
